@@ -1,5 +1,3 @@
-require 'tzinfo/country_index_definition'
-
 module TZInfo
   module Indexes
     module Countries
@@ -43,6 +41,7 @@ module TZInfo
         c.timezone 'Antarctica/Vostok', -392, 5, 1069, 10, 'Vostok Station, S Magnetic Pole'
         c.timezone 'Antarctica/DumontDUrville', -200, 3, 8401, 60, 'Dumont-d\'Urville Station, Terre Adelie'
         c.timezone 'Antarctica/Syowa', -124211, 1800, 3959, 100, 'Syowa Station, E Ongul I'
+        c.timezone 'Antarctica/Macquarie', -109, 2, 3179, 20, 'Macquarie Island Station, Macquarie Island'
       end
       country 'AR', 'Argentina' do |c|
         c.timezone 'America/Argentina/Buenos_Aires', -173, 5, -1169, 20, 'Buenos Aires (BA, CF)'
@@ -298,8 +297,8 @@ module TZInfo
         c.timezone 'Atlantic/Stanley', -517, 10, -1157, 20
       end
       country 'FM', 'Micronesia' do |c|
-        c.timezone 'Pacific/Truk', 89, 12, 9107, 60, 'Truk (Chuuk) and Yap'
-        c.timezone 'Pacific/Ponape', 209, 30, 9493, 60, 'Ponape (Pohnpei)'
+        c.timezone 'Pacific/Chuuk', 89, 12, 9107, 60, 'Chuuk (Truk) and Yap'
+        c.timezone 'Pacific/Pohnpei', 209, 30, 9493, 60, 'Pohnpei (Ponape)'
         c.timezone 'Pacific/Kosrae', 319, 60, 9779, 60, 'Kosrae'
       end
       country 'FO', 'Faroe Islands' do |c|
@@ -568,11 +567,15 @@ module TZInfo
         c.timezone 'America/Mexico_City', 97, 5, -1983, 20, 'Central Time - most locations'
         c.timezone 'America/Cancun', 253, 12, -2603, 30, 'Central Time - Quintana Roo'
         c.timezone 'America/Merida', 629, 30, -5377, 60, 'Central Time - Campeche, Yucatan'
-        c.timezone 'America/Monterrey', 77, 3, -6019, 60, 'Central Time - Coahuila, Durango, Nuevo Leon, Tamaulipas'
+        c.timezone 'America/Monterrey', 77, 3, -6019, 60, 'Mexican Central Time - Coahuila, Durango, Nuevo Leon, Tamaulipas away from US border'
+        c.timezone 'America/Matamoros', 155, 6, -195, 2, 'US Central Time - Coahuila, Durango, Nuevo Leon, Tamaulipas near US border'
         c.timezone 'America/Mazatlan', 1393, 60, -1277, 12, 'Mountain Time - S Baja, Nayarit, Sinaloa'
-        c.timezone 'America/Chihuahua', 859, 30, -1273, 12, 'Mountain Time - Chihuahua'
+        c.timezone 'America/Chihuahua', 859, 30, -1273, 12, 'Mexican Mountain Time - Chihuahua away from US border'
+        c.timezone 'America/Ojinaga', 887, 30, -1253, 12, 'US Mountain Time - Chihuahua near US border'
         c.timezone 'America/Hermosillo', 436, 15, -3329, 30, 'Mountain Standard Time - Sonora'
-        c.timezone 'America/Tijuana', 488, 15, -7021, 60, 'Pacific Time'
+        c.timezone 'America/Tijuana', 488, 15, -7021, 60, 'US Pacific Time - Baja California near US border'
+        c.timezone 'America/Santa_Isabel', 303, 10, -1723, 15, 'Mexican Pacific Time - Baja California away from US border'
+        c.timezone 'America/Bahia_Banderas', 104, 5, -421, 4, 'Mexican Central Time - Bahia de Banderas'
       end
       country 'MY', 'Malaysia' do |c|
         c.timezone 'Asia/Kuala_Lumpur', 19, 6, 1017, 10, 'peninsular Malaysia'
@@ -683,18 +686,19 @@ module TZInfo
         c.timezone 'Europe/Kaliningrad', 3283, 60, 41, 2, 'Moscow-01 - Kaliningrad'
         c.timezone 'Europe/Moscow', 223, 4, 451, 12, 'Moscow+00 - west Russia'
         c.timezone 'Europe/Volgograd', 731, 15, 533, 12, 'Moscow+00 - Caspian Sea'
-        c.timezone 'Europe/Samara', 266, 5, 1003, 20, 'Moscow+01 - Samara, Udmurtia'
+        c.timezone 'Europe/Samara', 266, 5, 1003, 20, 'Moscow - Samara, Udmurtia'
         c.timezone 'Asia/Yekaterinburg', 1137, 20, 303, 5, 'Moscow+02 - Urals'
         c.timezone 'Asia/Omsk', 55, 1, 367, 5, 'Moscow+03 - west Siberia'
         c.timezone 'Asia/Novosibirsk', 1651, 30, 995, 12, 'Moscow+03 - Novosibirsk'
+        c.timezone 'Asia/Novokuznetsk', 215, 4, 5227, 60, 'Moscow+03 - Novokuznetsk'
         c.timezone 'Asia/Krasnoyarsk', 3361, 60, 557, 6, 'Moscow+04 - Yenisei River'
         c.timezone 'Asia/Irkutsk', 784, 15, 313, 3, 'Moscow+05 - Lake Baikal'
         c.timezone 'Asia/Yakutsk', 62, 1, 389, 3, 'Moscow+06 - Lena River'
         c.timezone 'Asia/Vladivostok', 259, 6, 1979, 15, 'Moscow+07 - Amur River'
         c.timezone 'Asia/Sakhalin', 1409, 30, 1427, 10, 'Moscow+07 - Sakhalin Island'
         c.timezone 'Asia/Magadan', 1787, 30, 754, 5, 'Moscow+08 - Magadan'
-        c.timezone 'Asia/Kamchatka', 3181, 60, 3173, 20, 'Moscow+09 - Kamchatka'
-        c.timezone 'Asia/Anadyr', 259, 4, 10649, 60, 'Moscow+10 - Bering Sea'
+        c.timezone 'Asia/Kamchatka', 3181, 60, 3173, 20, 'Moscow+08 - Kamchatka'
+        c.timezone 'Asia/Anadyr', 259, 4, 10649, 60, 'Moscow+08 - Bering Sea'
       end
       country 'RW', 'Rwanda' do |c|
         c.timezone 'Africa/Kigali', -39, 20, 451, 15
