@@ -1,5 +1,3 @@
-require 'tzinfo/timezone_index_definition'
-
 module TZInfo
   module Indexes
     module Timezones
@@ -81,6 +79,7 @@ module TZInfo
       timezone 'America/Atikokan'
       linked_timezone 'America/Atka'
       timezone 'America/Bahia'
+      timezone 'America/Bahia_Banderas'
       timezone 'America/Barbados'
       timezone 'America/Belem'
       timezone 'America/Belize'
@@ -153,6 +152,7 @@ module TZInfo
       timezone 'America/Manaus'
       linked_timezone 'America/Marigot'
       timezone 'America/Martinique'
+      timezone 'America/Matamoros'
       timezone 'America/Mazatlan'
       linked_timezone 'America/Mendoza'
       timezone 'America/Menominee'
@@ -171,6 +171,7 @@ module TZInfo
       timezone 'America/Noronha'
       timezone 'America/North_Dakota/Center'
       timezone 'America/North_Dakota/New_Salem'
+      timezone 'America/Ojinaga'
       timezone 'America/Panama'
       timezone 'America/Pangnirtung'
       timezone 'America/Paramaribo'
@@ -187,6 +188,7 @@ module TZInfo
       timezone 'America/Resolute'
       timezone 'America/Rio_Branco'
       linked_timezone 'America/Rosario'
+      timezone 'America/Santa_Isabel'
       timezone 'America/Santarem'
       timezone 'America/Santiago'
       timezone 'America/Santo_Domingo'
@@ -215,6 +217,7 @@ module TZInfo
       timezone 'Antarctica/Casey'
       timezone 'Antarctica/Davis'
       timezone 'Antarctica/DumontDUrville'
+      timezone 'Antarctica/Macquarie'
       timezone 'Antarctica/Mawson'
       timezone 'Antarctica/McMurdo'
       timezone 'Antarctica/Palmer'
@@ -277,6 +280,7 @@ module TZInfo
       timezone 'Asia/Manila'
       timezone 'Asia/Muscat'
       timezone 'Asia/Nicosia'
+      timezone 'Asia/Novokuznetsk'
       timezone 'Asia/Novosibirsk'
       timezone 'Asia/Omsk'
       timezone 'Asia/Oral'
@@ -508,6 +512,7 @@ module TZInfo
       timezone 'Pacific/Apia'
       timezone 'Pacific/Auckland'
       timezone 'Pacific/Chatham'
+      timezone 'Pacific/Chuuk'
       timezone 'Pacific/Easter'
       timezone 'Pacific/Efate'
       timezone 'Pacific/Enderbury'
@@ -533,7 +538,8 @@ module TZInfo
       timezone 'Pacific/Pago_Pago'
       timezone 'Pacific/Palau'
       timezone 'Pacific/Pitcairn'
-      timezone 'Pacific/Ponape'
+      timezone 'Pacific/Pohnpei'
+      linked_timezone 'Pacific/Ponape'
       timezone 'Pacific/Port_Moresby'
       timezone 'Pacific/Rarotonga'
       timezone 'Pacific/Saipan'
@@ -541,7 +547,7 @@ module TZInfo
       timezone 'Pacific/Tahiti'
       timezone 'Pacific/Tarawa'
       timezone 'Pacific/Tongatapu'
-      timezone 'Pacific/Truk'
+      linked_timezone 'Pacific/Truk'
       timezone 'Pacific/Wake'
       timezone 'Pacific/Wallis'
       linked_timezone 'Pacific/Yap'
