@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2005-2006 Philip Ross
+# Copyright (c) 2005-2010 Philip Ross
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,9 +21,6 @@
 #++
 
 require 'date'
-require 'tzinfo/country'
-require 'tzinfo/time_or_datetime'
-require 'tzinfo/timezone_period'
 
 module TZInfo
   # Indicate a specified time in a local timezone has more than one
@@ -78,11 +75,11 @@ module TZInfo
     def self.get(identifier)
       instance = @@loaded_zones[identifier]
       unless instance  
-        raise InvalidTimezoneIdentifier, 'Invalid identifier' if identifier !~ /^[A-z0-9\+\-_]+(\/[A-z0-9\+\-_]+)*$/
+        raise InvalidTimezoneIdentifier, 'Invalid identifier' if identifier !~ /^[A-Za-z0-9\+\-_]+(\/[A-Za-z0-9\+\-_]+)*$/
         identifier = identifier.gsub(/-/, '__m__').gsub(/\+/, '__p__')
         begin
           # Use a temporary variable to avoid an rdoc warning
-          file = "tzinfo/definitions/#{identifier}"
+          file = "tzinfo/definitions/#{identifier}".untaint
           require file
           
           m = Definitions
